#!/bin/sh

set -e
set -u

config_dir=$(mktemp -d)

echo "generating self-signed certificate..."
openssl req -x509 -newkey rsa:2048 -sha256 -days 3650 \
    -nodes -keyout ${config_dir}/ssl.key -out ${config_dir}/ssl.crt \
    -subj "/CN=${PROXY_DOMAIN}" \
    -addext "subjectAltName=DNS:${PROXY_DOMAIN},DNS:*.${PROXY_DOMAIN}" \
    >/dev/null 2>&1

cat >${config_dir}/nginx.conf <<EOF
include /etc/nginx/modules-enabled/*.conf;
worker_processes auto;
pid ${config_dir}/nginx.pid;
error_log stderr;

events {
	worker_connections 8192;
}

http {
	sendfile on;
	tcp_nopush on;
	tcp_nodelay on;
	access_log ${config_dir}/access.log;
	include /etc/nginx/mime.types;
	include /etc/nginx/conf.d/*.conf;

	upstream target {
		server ${PROXY_BACKEND_ADDR};
	}

	server {
		listen [::]:${PROXY_PORT:-8443} http2 ssl default_server ipv6only=off;
		server_name *.${PROXY_DOMAIN} ${PROXY_DOMAIN};
		ssl_certificate ${config_dir}/ssl.crt;
		ssl_certificate_key ${config_dir}/ssl.key;
		location / {
			include /etc/nginx/proxy_params;
			proxy_pass http://target;
		}
	}
}
EOF

echo "testing NGINX configuration..."
nginx -c ${config_dir}/nginx.conf -t
if [ $? -gt 0 ]; then
    echo "ERROR!" >&2
    cat ${config_dir}/nginx.conf
    exit 2
fi

echo "starting NGINX..."
nginx -c ${config_dir}/nginx.conf -g 'daemon off;'

echo "NGINX has exited."
exit 0
